/*
 * Quoridor server and related libraries
 * Copyright (C) 2009-2010 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */
package cz.xelfi.quoridor.statistics;

import javax.xml.bind.annotation.XmlAttribute;
import java.util.Comparator;
/**
 *
 * @author Martin Rexa
 */
public class EloEntry {
    String player;
    double elo;
    int games;

    public static final Comparator<EloEntry> BEST_FIRST = new BestFirst();

    EloEntry(){
        super();
    }

    EloEntry(String player, double elo, int games){
        super();
        this.player = player;
        this.elo = elo;
        this.games = games;
    }

    @XmlAttribute
    public String getPlayer(){
        return player;
    }

    @XmlAttribute
    public Double getElo(){
        return elo;
    }

    @XmlAttribute
    public Integer getGames(){
        return games;
    }

    public String toString(){
        return "Player: " + player + ", ELO: " + elo + ", Games: " + games;
    }

    private static final class BestFirst implements Comparator<EloEntry> {
        public int compare(EloEntry e1, EloEntry e2) {
            if(e1.elo > e2.elo)
                return -1;
            else if(e1.elo < e2.elo)
                return 1;
            else return e1.player.compareTo(e2.player);
        }
    }

}
