/*
 * Quoridor server and related libraries
 * Copyright (C) 2009-2010 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */

package cz.xelfi.quoridor.statistics;

import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author Martin Rexa
 */
public class EloTest extends Object {

    public EloTest() throws Exception {
    }

    @Test public void testEloList() throws Exception {
        EloList eloList = new EloList();
        eloList.putResult("p1", "p2");
        assertFalse("empty list", eloList.getFinalList().isEmpty());
        eloList.putResult("p3", "p4");
        assertTrue("wrong list", eloList.getFinalList().get(0).getElo().equals(eloList.getFinalList().get(1).getElo()));
        eloList.putResult("p2", "p1");
        eloList.putResult("p2", "p1");
        eloList.putResult("p2", "p1");
        assertTrue("wrong list", eloList.getFinalList().get(0).player.equals("p2"));
    }

    @Test public void testEloResults() throws Exception {
        EloList eloList = new EloList();
        setTestPlayer(eloList, "p1", 1335, 120);
        setTestPlayer(eloList, "p2", 1380, 20);
        setTestPlayer(eloList, "p3", 1264, 110);
        setTestPlayer(eloList, "p4", 1281, 140);
        printList(eloList);
//        eloList.putResult("p1", "p2");
        eloList.putResult("p1", "p3");
        eloList.putResult("p1", "p4");
        printList(eloList);
        eloList.putResult("p2", "p1");
        eloList.putResult("p1", "p2");
        printList(eloList);
    }

    private void setTestPlayer(EloList eloList, String player, double elo, int games){
        eloList.players.put(player, elo);
        eloList.playerGames.put(player, games);
    }

    private void printList(EloList eloList){
        for(EloEntry entry: eloList.getFinalList()){
            System.out.println(entry);
        }
        System.out.println("------------");
    }

}
